gainslift gainsliftTable Function
1 | gainsliftTable(predictions, responses, type = 'cum', cost = 0, benefit = 0)
|
predictions |
A dataframe containing one or multiple numeric vectors of predicted response values.
All of the vectors must have the same length as |
responses |
a numeric vector of actual response values. |
type |
'cum' will give a cumulative table. 'decile' will give a cumulative decile table. 'noncum' will give a non-cumulative decile table. (The default is set as 'cum') |
cost |
a numeric value of the cost of an incorrect classification. e.g. If the cost of mailing a target is $5, then the cost should be set as 5. |
benefit |
a numeric value of the benefit of a correct classification. e.g. If the value of a responder is $20, then the benefit should be set as 25. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.